@@ -270,6 +270,44 @@ class UserTest(unittest.TestCase):
     user = twitter.User.NewFromJsonDict(data)
     self.assertEqual(self._GetSampleUser(), user)
 
+class TrendTest(unittest.TestCase):
+
+  SAMPLE_JSON = '''{"name": "Kesuke Miyagi", "query": "Kesuke Miyagi"}'''
+
+  def _GetSampleTrend(self):
+    return twitter.Trend(name='Kesuke Miyagi',
+                         query='Kesuke Miyagi',
+                         timestamp='Fri Jan 26 23:17:14 +0000 2007')
+
+  def testInit(self):
+    '''Test the twitter.Trend constructor'''
+    trend = twitter.Trend(name='Kesuke Miyagi',
+                          query='Kesuke Miyagi',
+                          timestamp='Fri Jan 26 23:17:14 +0000 2007')
+
+  def testProperties(self):
+    '''Test all of the twitter.Trend properties'''
+    trend = twitter.Trend()
+    trend.name = 'Kesuke Miyagi'
+    self.assertEqual('Kesuke Miyagi', trend.name)
+    trend.query = 'Kesuke Miyagi'
+    self.assertEqual('Kesuke Miyagi', trend.query)
+    trend.timestamp = 'Fri Jan 26 23:17:14 +0000 2007'
+    self.assertEqual('Fri Jan 26 23:17:14 +0000 2007', trend.timestamp)
+
+  def testNewFromJsonDict(self):
+    '''Test the twitter.Trend NewFromJsonDict method'''
+    data = simplejson.loads(TrendTest.SAMPLE_JSON)
+    trend = twitter.Trend.NewFromJsonDict(data, timestamp='Fri Jan 26 23:17:14 +0000 2007')
+    self.assertEqual(self._GetSampleTrend(), trend)
+
+  def testEq(self):
+    '''Test the twitter.Trend __eq__ method'''
+    trend = twitter.Trend()
+    trend.name = 'Kesuke Miyagi'
+    trend.query = 'Kesuke Miyagi'
+    trend.timestamp = 'Fri Jan 26 23:17:14 +0000 2007'
+    self.assertEqual(trend, self._GetSampleTrend())
 
 class FileCacheTest(unittest.TestCase):
 
@@ -318,33 +356,24 @@ class ApiTest(unittest.TestCase):
     api = twitter.Api(consumer_key='CONSUMER_KEY',
                       consumer_secret='CONSUMER_SECRET',
                       access_token_key='OAUTH_TOKEN',
-                      access_token_secret='OAUTH_SECRET', 
+                      access_token_secret='OAUTH_SECRET',
                       cache=None)
     api.SetUrllib(self._urllib)
     self._api = api
 
   def testTwitterError(self):
     '''Test that twitter responses containing an error message are wrapped.'''
-    self._AddHandler('https://api.twitter.com/1/statuses/public_timeline.json',
+    self._AddHandler('https://api.twitter.com/1/statuses/user_timeline.json',
                      curry(self._OpenTestData, 'public_timeline_error.json'))
     # Manually try/catch so we can check the exception's value
     try:
-      statuses = self._api.GetPublicTimeline()
+      statuses = self._api.GetUserTimeline()
     except twitter.TwitterError, error:
       # If the error message matches, the test passes
       self.assertEqual('test error', error.message)
     else:
       self.fail('TwitterError expected')
 
-  def testGetPublicTimeline(self):
-    '''Test the twitter.Api GetPublicTimeline method'''
-    self._AddHandler('https://api.twitter.com/1/statuses/public_timeline.json?since_id=12345',
-                     curry(self._OpenTestData, 'public_timeline.json'))
-    statuses = self._api.GetPublicTimeline(since_id=12345)
-    # This is rather arbitrary, but spot checking is better than nothing
-    self.assertEqual(20, len(statuses))
-    self.assertEqual(89497702, statuses[0].id)
-
   def testGetUserTimeline(self):
     '''Test the twitter.Api GetUserTimeline method'''
     self._AddHandler('https://api.twitter.com/1/statuses/user_timeline/kesuke.json?count=1',
@@ -386,6 +415,17 @@ class ApiTest(unittest.TestCase):
     # This is rather arbitrary, but spot checking is better than nothing
     self.assertEqual(u'Моё судно на воздушной подушке полно угрей', status.text)
 
+  def testPostUpdateLatLon(self):
+    '''Test the twitter.Api PostUpdate method, when used in conjunction with latitude and longitude'''
+    self._AddHandler('https://api.twitter.com/1/statuses/update.json',
+                     curry(self._OpenTestData, 'update_latlong.json'))
+    #test another update with geo parameters, again test somewhat arbitrary
+    status = self._api.PostUpdate(u'Моё судно на воздушной подушке полно угрей'.encode('utf8'), latitude=54.2, longitude=-2)
+    self.assertEqual(u'Моё судно на воздушной подушке полно угрей', status.text)
+    self.assertEqual(u'Point',status.GetGeo()['type'])
+    self.assertEqual(26.2,status.GetGeo()['coordinates'][0])
+    self.assertEqual(127.5,status.GetGeo()['coordinates'][1])
+
   def testGetReplies(self):
     '''Test the twitter.Api GetReplies method'''
     self._AddHandler('https://api.twitter.com/1/statuses/replies.json?page=1',
@@ -393,6 +433,13 @@ class ApiTest(unittest.TestCase):
     statuses = self._api.GetReplies(page=1)
     self.assertEqual(36657062, statuses[0].id)
 
+  def testGetRetweetsOfMe(self):
+    '''Test the twitter.API GetRetweetsOfMe method'''
+    self._AddHandler('https://api.twitter.com/1/statuses/retweets_of_me.json',
+        curry(self._OpenTestData, 'retweets_of_me.json'))
+    retweets = self._api.GetRetweetsOfMe()
+    self.assertEqual(253650670274637824, retweets[0].id)
+
   def testGetFriends(self):
     '''Test the twitter.Api GetFriends method'''
     self._AddHandler('https://api.twitter.com/1/statuses/friends.json?cursor=123',
@@ -403,9 +450,9 @@ class ApiTest(unittest.TestCase):
 
   def testGetFollowers(self):
     '''Test the twitter.Api GetFollowers method'''
-    self._AddHandler('https://api.twitter.com/1/statuses/followers.json?page=1',
+    self._AddHandler('https://api.twitter.com/1/statuses/followers.json?cursor=-1',
                      curry(self._OpenTestData, 'followers.json'))
-    users = self._api.GetFollowers(page=1)
+    users = self._api.GetFollowers()
     # This is rather arbitrary, but spot checking is better than nothing
     alexkingorg = [u.status for u in users if u.screen_name == 'alexkingorg']
     self.assertEqual(89554432, alexkingorg[0].id)
@@ -498,10 +545,13 @@ class MockUrllib(object):
 
   def HTTPSHandler(self, *args, **kwargs):
       return None
-  
+
   def OpenerDirector(self):
       return self.build_opener()
 
+  def ProxyHandler(self,*args,**kwargs):
+      return None
+
 class MockOpener(object):
   '''A mock opener for urllib'''
 
@@ -512,20 +562,20 @@ class MockOpener(object):
   def open(self, url, data=None):
     if self._opened:
       raise Exception('MockOpener already opened.')
-  
+
     # Remove parameters from URL - they're only added by oauth and we
-    # don't want to test oauth 
+    # don't want to test oauth
     if '?' in url:
         # We split using & and filter on the beginning of each key
         # This is crude but we have to keep the ordering for now
         (url, qs) = url.split('?')
-        
-        tokens = [token for token in qs.split('&') 
+
+        tokens = [token for token in qs.split('&')
                   if not token.startswith('oauth')]
-        
+
         if len(tokens) > 0:
             url = "%s?%s"%(url, '&'.join(tokens))
-  
+
     if url in self._handlers:
       self._opened = True
       return self._handlers[url]()
